@@ -12,9 +12,6 @@
 #include <KLocalizedString>
 #include <KCrash>
 #include <KDBusService>
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#include <Kdelibs4ConfigMigrator>
-#endif
 
 #include <QApplication>
 #include <QCommandLineParser>
@@ -25,7 +22,7 @@
 
 int main(int argc, char *argv[])
 {
-	KLocalizedString::setApplicationDomain("blinken");
+	KLocalizedString::setApplicationDomain(QByteArrayLiteral("blinken"));
 
 	QApplication app(argc, argv);
 	KAboutData about(QStringLiteral("blinken"), i18n("Blinken"), QStringLiteral(BLINKEN_VERSION_STRING), i18n("A memory enhancement game"), KAboutLicense::GPL, i18n("© 2005-2007 Albert Astals Cid\nSPDX-FileCopyrightText: 2005-2007 Danny Allen "));
@@ -36,12 +33,6 @@ int main(int argc, char *argv[])
 	KAboutData::setApplicationData(about);
 
 	KCrash::initialize();
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-	Kdelibs4ConfigMigrator migrate(QStringLiteral("blinken"));
-	migrate.setConfigFiles(QStringList() << QStringLiteral("blinkenrc"));
-	migrate.migrate();
-#endif
-
 
 	QCommandLineParser parser;
 	about.setupCommandLine(&parser);
